@@ -1,8 +1,7 @@
-from ..signaler.signaler_base import SignalerBase
+from ..signaler.base_signaler import BaseSignaler
 
-
-class NoSignaler(SignalerBase):
+class NoSignaler(BaseSignaler):
     """Implement no signaller for cache"""
 
     def __init__(self) -> None:
-        super().__init__(None, None)
+        super().__init__(None, None)
\ No newline at end of file
