@@ -1,14 +1,16 @@
 from bclib.context.client_source_context import ClientSourceContext
-from bclib.context.client_source_member_context import ClientSourceMemberContext
+from bclib.context.client_source_member_context import \
+    ClientSourceMemberContext
 from bclib.context.context import Context
-from bclib.context.restful_context import RESTfulContext
-from bclib.context.web_context import WebContext
-from bclib.context.request_context import RequestContext
-from bclib.context.rabbit_context import RabbitContext
-from bclib.context.socket_context import SocketContext
 from bclib.context.merge_type import MergeType
+from bclib.context.rabbit_context import RabbitContext
+from bclib.context.request_context import RequestContext
+from bclib.context.restful_context import RESTfulContext
 from bclib.context.server_source_context import ServerSourceContext
-from bclib.context.server_source_member_context import ServerSourceMemberContext
+from bclib.context.server_source_member_context import \
+    ServerSourceMemberContext
+from bclib.context.socket_context import SocketContext
 from bclib.context.source_context import SourceContext
 from bclib.context.source_member_context import SourceMemberContext
-from bclib.context.named_pipe_context import NamedPipeContext
+from bclib.context.web_context import WebContext
+from bclib.context.websocket_context import WebSocketContext
