@@ -1,16 +1,18 @@
 import json
 from typing import TYPE_CHECKING
-from bclib.utility import DictEx
-from ..context.json_base_request_context import JsonBaseRequestContext
 from urllib.parse import parse_qsl
 
+from bclib.utility import DictEx
+
+from ..context.json_base_request_context import JsonBaseRequestContext
+
 if TYPE_CHECKING:
-    from .. import dispatcher
+    from .. import dispatcher, listener
 
 
 class RESTfulContext(JsonBaseRequestContext):
-    def __init__(self, cms_object: dict, dispatcher: 'dispatcher.IDispatcher') -> None:
-        super().__init__(cms_object, dispatcher)
+    def __init__(self, cms_object: dict, dispatcher: 'dispatcher.IDispatcher', message_object: 'listener.SocketMessage') -> None:
+        super().__init__(cms_object, dispatcher, message_object)
         temp_data = None
         if self.cms.form:
             temp_data = self.cms.form
@@ -22,7 +24,7 @@ class RESTfulContext(JsonBaseRequestContext):
                     temp_data = dict()
                     for key, value in parse_qsl(body):
                         temp_data[key.strip()] = value
-                else:
+                elif content_type.find("json") > -1:
                     try:
                         temp_data = json.loads(self.cms.request.body)
                     except Exception as ex:
