@@ -1,7 +1,8 @@
-from bclib.dispatcher.dispatcher import Dispatcher
-from bclib.dispatcher.idispatcher import IDispatcher
-from bclib.dispatcher.socket_dispatcher import SocketDispatcher
 from bclib.dispatcher.dev_server_dispatcher import DevServerDispatcher
-from bclib.dispatcher.routing_dispatcher import RoutingDispatcher
-from bclib.dispatcher.named_pipe_dispatcher import NamedPipeDispatcher
+from bclib.dispatcher.dispatcher import Dispatcher
 from bclib.dispatcher.endpoint_dispatcher import EndpointDispatcher
+from bclib.dispatcher.idispatcher import IDispatcher
+from bclib.dispatcher.routing_dispatcher import RoutingDispatcher
+from bclib.dispatcher.socket_dispatcher import SocketDispatcher
+from bclib.dispatcher.websocket_session import WebSocketSession
+from bclib.dispatcher.websocket_session_manager import WebSocketSessionManager
