@@ -1,13 +1,13 @@
 """Dispatcher base class module"""
 from abc import ABC, abstractmethod
 import asyncio
-from typing import Callable, Any, TYPE_CHECKING, Coroutine
+from typing import Callable, Any, TYPE_CHECKING, Coroutine, Optional
 
 from bclib.db_manager import DbManager
 from bclib.cache import CacheManager
 from bclib.listener import Message
 from bclib.utility import DictEx
-
+from bclib.logger import LogObject
 if TYPE_CHECKING:
     from context import Context
 
@@ -60,8 +60,11 @@ class IDispatcher(ABC):
     def run_in_background(self, callback: Callable, *args: Any) -> asyncio.Future:
         """helper for run function in background thread"""
 
-    def log_async(self, **kwargs: 'dict[str,Any]'):
+    def new_object_log(self, schema_name: str, routing_key: Optional[str] = None, **kwargs) -> LogObject:
+        """Create new log object"""
+
+    async def log_async(self, log_object: LogObject = None, **kwargs):
         """log params"""
 
-    def log_in_background(self, **kwargs: 'dict[str,Any]') -> Coroutine:
+    def log_in_background(self, log_object: LogObject = None, **kwargs) -> Coroutine:
         """log params in background precess"""
