@@ -3,27 +3,37 @@ import inspect
 import json
 import re
 from struct import error
-from typing import Callable, Any, Coroutine
-from abc import abstractmethod
+from typing import Any, Callable, Coroutine, Optional
 
+from bclib.context import (ClientSourceContext, Context, RequestContext,
+                           RESTfulContext, ServerSourceContext, SocketContext,
+                           WebContext, WebSocketContext)
+from bclib.dispatcher.dispatcher import Dispatcher
+from bclib.dispatcher.dispatcher_helper import DispatcherHelper
+from bclib.dispatcher.websocket_session_manager import WebSocketSessionManager
+from bclib.listener import (HttpBaseDataType, Message, MessageType,
+                            ReceiveMessage)
+from bclib.listener.web_message import WebMessage
+from bclib.listener.websocket_message import WebSocketMessage
 from bclib.utility import DictEx
 
-from bclib.context import ClientSourceContext, RESTfulContext, WebContext, RequestContext, Context, SocketContext, ServerSourceContext, NamedPipeContext
-from bclib.listener import Message, MessageType, HttpBaseDataType
-
-from ..dispatcher.dispatcher_helper import DispatcherHelper
-from ..dispatcher.dispatcher import Dispatcher
-
 
 class RoutingDispatcher(Dispatcher, DispatcherHelper):
 
-    def __init__(self, options: dict):
-        super().__init__(options)
+    def __init__(self, options: dict, loop: asyncio.AbstractEventLoop = None):
+        super().__init__(options=options, loop=loop)
         self.__default_router = self.options.defaultRouter\
             if 'defaultRouter' in self.options and isinstance(self.options.defaultRouter, str)\
             else None
         self.name = self.options["name"] if self.options.has("name") else None
         self.__log_name = f"{self.name}: " if self.name else ''
+
+        # Initialize WebSocket session manager
+        self.__ws_manager = WebSocketSessionManager(
+            on_message_receive_async=self._on_message_receive_async,
+            heartbeat_interval=30.0
+        )
+
         if self.options.has('router'):
             router = self.options.router
             if isinstance(router, str):
@@ -36,8 +46,7 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
         elif self.__default_router:
             self.__context_type_detector: 'Callable[[str],str]' = lambda _: self.__default_router
         else:
-            raise error(
-                "Invalid routing config! Please at least set one of 'router' or 'defaultRouter' property in host options.")
+            print("'router' or 'defaultRouter' property not found in host options! so only websocket and socket contexts will be supported.")
 
     def init_router_lookup(self):
         """create router lookup dictionary"""
@@ -83,11 +92,13 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
             response = await self.dispatch_async(context)
             ret_val: Message = None
             if context.is_adhoc:
-                message_result = json.dumps(response).encode("utf-8")
-                ret_val = Message.create_add_hock(
-                    message.session_id, message_result)
+                # Pass raw response object; message implementation will handle serialization
+                ret_val = message.create_response_message(
+                    message.session_id,
+                    response
+                )
             return ret_val
-        except error as ex:
+        except Exception as ex:
             print(f"Error in process received message {ex}")
             raise ex
 
@@ -96,50 +107,68 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
 
         ret_val: RequestContext = None
         context_type = None
-        cms_object: dict = None
-        url: str = None
-        request_id: str = None
-        method: str = None
-        message_json: dict = None
-        if message.buffer:
-            message_string = message.buffer.decode("utf-8")
-            message_json = json.loads(message_string)
-            cms_object = message_json[HttpBaseDataType.CMS] if HttpBaseDataType.CMS in message_json else None
-            if cms_object:
+        cms_object: Optional[dict] = None
+        url: Optional[str] = None
+        request_id: Optional[str] = None
+        method: Optional[str] = None
+        message_json: Optional[dict] = None
+        if isinstance(message, WebMessage):
+            message_json = message.cms_object
+            cms_object = message_json.get(
+                HttpBaseDataType.CMS) if message_json else None
+        elif isinstance(message, WebSocketMessage):
+            context_type = "websocket"
+            cms_object = message.session.cms
+        elif message.buffer is not None:
+            message_json = json.loads(message.buffer)
+            cms_object = message_json.get(
+                HttpBaseDataType.CMS) if message_json else None
+        if cms_object:
+            if 'request' in cms_object:
                 req = cms_object["request"]
-                request_id = req['request-id']
-                method = req['methode']
+            else:
+                raise KeyError("request key not found in cms object")
+            if 'full-url' in req:
                 url = req["full-url"]
+            else:
+                raise KeyError("full-url key not found in request")
+            request_id = req['request-id'] if 'request-id' in req else 'none'
+            method = req['methode'] if 'methode' in req else 'none'
         if message.type == MessageType.AD_HOC:
             if url or self.__default_router is None:
                 context_type = self.__context_type_detector(url)
             else:
                 context_type = self.__default_router
-        else:
+        elif context_type is None:
             context_type = "socket"
         if self.log_request:
             print(
                 f"{self.__log_name}({context_type}::{message.type.name}){f' - {request_id} {method} {url} ' if cms_object else ''}")
 
         if context_type == "client_source":
-            ret_val = ClientSourceContext(cms_object, self)
+            ret_val = ClientSourceContext(cms_object, self, message)
         elif context_type == "restful":
-            ret_val = RESTfulContext(cms_object, self)
+            ret_val = RESTfulContext(cms_object, self, message)
         elif context_type == "server_source":
             ret_val = ServerSourceContext(message_json, self)
         elif context_type == "web":
-            ret_val = WebContext(cms_object, self)
+            ret_val = WebContext(cms_object, self, message)
         elif context_type == "socket":
             ret_val = SocketContext(cms_object, self, message, message_json)
-        elif context_type == "named_pipe":
-            ret_val = NamedPipeContext(message_json, message_string, self)
+        elif context_type == "websocket":
+            ret_val = WebSocketContext(cms_object, self, message)
         elif context_type is None:
-            raise Exception(f"No context found for '{url}'")
+            raise NameError(f"No context found for '{url}'")
         else:
-            raise Exception(
+            raise NameError(
                 f"Configured context type '{context_type}' not found for '{url}'")
         return ret_val
 
+    @property
+    def ws_manager(self) -> WebSocketSessionManager:
+        """Get WebSocket session manager"""
+        return self.__ws_manager
+
     def run_in_background(self, callback: 'Callable|Coroutine', *args: Any) -> asyncio.Future:
         """helper for run function in background thread"""
 
@@ -150,10 +179,10 @@ class RoutingDispatcher(Dispatcher, DispatcherHelper):
 
     async def send_message_async(self, message: MessageType) -> bool:
         """Send message to endpoint"""
-        raise Exception(
+        raise NotImplementedError(
             "Send ad-hoc message not support in this type of dispatcher")
 
-    def cache(self, seconds: int = 0, key: str = None):
+    def cache(self, life_time: "int" = 0, key: "str" = None):
         """Cache result of function for seconds of time or until signal by key for clear"""
 
-        return self.cache_manager.cache_decorator(seconds, key)
+        return self.cache_manager.cache_decorator(key, life_time)
