@@ -4,8 +4,8 @@ from ..listener import Endpoint, Message, SocketListener
 
 
 class SocketDispatcher(RoutingDispatcher):
-    def __init__(self, options: dict):
-        super().__init__(options)
+    def __init__(self, options: dict,loop:asyncio.AbstractEventLoop=None):
+        super().__init__(options=options,loop=loop)
         self.__lock = asyncio.Lock()
         self.__listener = SocketListener(
             Endpoint(self.options.receiver),
