@@ -1,12 +1,24 @@
 """Main module of bclib.wrapper for all exist module that need in basic coding"""
 
-from bclib.dispatcher import RoutingDispatcher, IDispatcher, SocketDispatcher, DevServerDispatcher, NamedPipeDispatcher, EndpointDispatcher
-from bclib.context import Context, WebContext, SocketContext, ClientSourceContext, ClientSourceMemberContext, RabbitContext, RESTfulContext, RequestContext, MergeType, ServerSourceContext, ServerSourceMemberContext, SourceContext, SourceMemberContext, NamedPipeContext
-from bclib.utility import DictEx, HttpStatusCodes, HttpMimeTypes, ResponseTypes, HttpHeaders, WindowsNamedPipeHelper
-from bclib.listener import Message, MessageType, HttpBaseDataType, HttpBaseDataName
-from bclib.predicate import Predicate
-from bclib.exception import ShortCircuitErr, UnauthorizedErr, HandlerNotFoundErr, InternalServerErr, NotFoundErr
+import asyncio
+
 from bclib import __version__
+from bclib.context import (ClientSourceContext, ClientSourceMemberContext,
+                           Context, MergeType, RabbitContext, RequestContext,
+                           RESTfulContext, ServerSourceContext,
+                           ServerSourceMemberContext, SocketContext,
+                           SourceContext, SourceMemberContext, WebContext,
+                           WebSocketContext)
+from bclib.db_manager import *
+from bclib.dispatcher import (DevServerDispatcher, EndpointDispatcher,
+                              IDispatcher, RoutingDispatcher, SocketDispatcher,
+                              WebSocketSession)
+from bclib.exception import *
+from bclib.listener import (HttpBaseDataName, HttpBaseDataType, Message,
+                            MessageType)
+from bclib.predicate import Predicate
+from bclib.utility import (DictEx, HttpHeaders, HttpMimeTypes, HttpStatusCodes,
+                           ResponseTypes, StaticFileHandler)
 
 
 def from_config(option_file_path: str, file_name: str = "host.json"):
@@ -21,26 +33,26 @@ def from_config(option_file_path: str, file_name: str = "host.json"):
 
 def from_list(hosts: 'dict[str,list[str]]'):
     """Create related RoutingDispatcher obj from path list object"""
+    import concurrent.futures
     import subprocess
-    import asyncio
 
     __print_splash(True)
     loop = asyncio.get_event_loop()
-    for host, args in hosts.items():
-        try:
+    with concurrent.futures.ThreadPoolExecutor(max_workers=len(hosts.items())) as executor:
+        tasks: list[asyncio.Future] = []
+        for host, args in hosts.items():
             args.append(f"-n {host}")
             args.append("-m")
-            loop.run_in_executor(None, subprocess.run, args)
-            print(f'{host} start runing from {args[1]}')
-        except Exception as ex:
-            print(ex)
+            tasks.append(loop.run_in_executor(executor, subprocess.run, args))
+            print(f'{host} start running from {args[1]}')
+        loop.run_until_complete(asyncio.gather(*tasks))
 
 
-def from_options(options: dict) -> RoutingDispatcher:
+def from_options(options: dict, loop: asyncio.AbstractEventLoop = None) -> RoutingDispatcher:
     """Create related RoutingDispatcher obj from config object"""
 
-    import sys
     import getopt
+    import sys
 
     multi: bool = False
     argumentList = sys.argv[1:]
@@ -63,13 +75,11 @@ def from_options(options: dict) -> RoutingDispatcher:
         __print_splash(False)
     ret_val: RoutingDispatcher = None
     if "server" in options:
-        ret_val = DevServerDispatcher(options)
-    elif "named_pipe" in options:
-        ret_val = NamedPipeDispatcher(options)
+        ret_val = DevServerDispatcher(options=options, loop=loop)
     elif "endpoint" in options:
-        ret_val = EndpointDispatcher(options)
+        ret_val = EndpointDispatcher(options=options, loop=loop)
     else:
-        ret_val = SocketDispatcher(options)
+        ret_val = SocketDispatcher(options=options, loop=loop)
     return ret_val
 
 
