@@ -21,3 +21,9 @@ class HttpBaseDataName:
     HTTP = "http"
     WEB_SERVER = "webserver"
     CONTENT = "content"
+    BLOB_CONTENT = "blob-content"
+    INDEX = "index"
+    HEADER_CODE = "headercode"
+    FILE_PATH = "filepath"
+    MIME = "mime"
+    GZIP = "gzip"
