@@ -1,7 +1,6 @@
 from bclib.utility.dict_ex import DictEx
-from bclib.utility.http_status_codes import HttpStatusCodes
-from bclib.utility.http_mime_types import HttpMimeTypes
-from bclib.utility.response_types import ResponseTypes
 from bclib.utility.http_headers import HttpHeaders
-from bclib.utility.windows_named_pipe_helper import WindowsNamedPipeHelper
-from bclib.utility.linux_named_pipe_helper import LinuxNamedPipeHelper
+from bclib.utility.http_mime_types import HttpMimeTypes
+from bclib.utility.http_status_codes import HttpStatusCodes
+from bclib.utility.response_types import ResponseTypes
+from bclib.utility.static_file_handler import StaticFileHandler
